All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 0/5] staging: mt7621-pci: cleanup
@ 2018-10-04 16:29 Mamta Shukla
  2018-10-04 16:32 ` [PATCH 1/5] staging: mt7621-pci: do not initialise statics to 0 Mamta Shukla
                   ` (4 more replies)
  0 siblings, 5 replies; 8+ messages in thread
From: Mamta Shukla @ 2018-10-04 16:29 UTC (permalink / raw)
  To: outreachy-kernel; +Cc: mamtashukla555, gregkh

Fix issues found with checkpatch.pl for mt7621-pci staging driver.

Mamta Shukla (5):
  staging: mt7621-pci: do not initialise statics to 0
  staging: mt7621-pci: spaces preferred around that '&'
  staging: mt7621-pci: spaces preferred around that '|'
  staging: mt7621-pci: spaces preferred around that '<<'
  staging: mt7621-pci: Prefer using the BIT macro

 drivers/staging/mt7621-pci/pci-mt7621.c | 50 ++++++++++++++++-----------------
 1 file changed, 25 insertions(+), 25 deletions(-)

-- 
1.9.1



^ permalink raw reply	[flat|nested] 8+ messages in thread

* [PATCH 1/5] staging: mt7621-pci: do not initialise statics to 0
  2018-10-04 16:29 [PATCH 0/5] staging: mt7621-pci: cleanup Mamta Shukla
@ 2018-10-04 16:32 ` Mamta Shukla
  2018-10-04 20:12   ` [Outreachy kernel] " Shraddha Barke
  2018-10-04 16:34 ` [PATCH 2/5] staging: mt7621-pci: spaces preferred around that '&' Mamta Shukla
                   ` (3 subsequent siblings)
  4 siblings, 1 reply; 8+ messages in thread
From: Mamta Shukla @ 2018-10-04 16:32 UTC (permalink / raw)
  To: outreachy-kernel; +Cc: mamtashukla555, gregkh

Remove initialisation to 0 for static global variable to fix checkpatch issue.
ERROR: do not initialise statics to 0

Signed-off-by: Mamta Shukla <mamtashukla555@gmail.com>
---
Removed initialisation to 0 for static global variable:
1.This type of variable iss initialised to 0 implicitly as per C coding
standard.
2.Also this will take space in .BSS segment of memory while linking.

 drivers/staging/mt7621-pci/pci-mt7621.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/drivers/staging/mt7621-pci/pci-mt7621.c b/drivers/staging/mt7621-pci/pci-mt7621.c
index ba1f117..3182d8a 100644
--- a/drivers/staging/mt7621-pci/pci-mt7621.c
+++ b/drivers/staging/mt7621-pci/pci-mt7621.c
@@ -122,7 +122,7 @@
 #define RALINK_PCIE_CLK_EN		BIT(21)
 
 #define MEMORY_BASE 0x0
-static int pcie_link_status = 0;
+static int pcie_link_status;
 
 /**
  * struct mt7621_pcie_port - PCIe port information
-- 
1.9.1



^ permalink raw reply related	[flat|nested] 8+ messages in thread

* [PATCH 2/5] staging: mt7621-pci: spaces preferred around that '&'
  2018-10-04 16:29 [PATCH 0/5] staging: mt7621-pci: cleanup Mamta Shukla
  2018-10-04 16:32 ` [PATCH 1/5] staging: mt7621-pci: do not initialise statics to 0 Mamta Shukla
@ 2018-10-04 16:34 ` Mamta Shukla
  2018-10-04 16:35 ` [PATCH 3/5] staging: mt7621-pci: spaces preferred around that '|' Mamta Shukla
                   ` (2 subsequent siblings)
  4 siblings, 0 replies; 8+ messages in thread
From: Mamta Shukla @ 2018-10-04 16:34 UTC (permalink / raw)
  To: outreachy-kernel; +Cc: mamtashukla555, gregkh

Add spaces around '&' to fix checkpatch issue.
CHECK: spaces preferred around that '&' (ctx:VxV)

Signed-off-by: Mamta Shukla <mamtashukla555@gmail.com>
---
 drivers/staging/mt7621-pci/pci-mt7621.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/drivers/staging/mt7621-pci/pci-mt7621.c b/drivers/staging/mt7621-pci/pci-mt7621.c
index 3182d8a..14aac08 100644
--- a/drivers/staging/mt7621-pci/pci-mt7621.c
+++ b/drivers/staging/mt7621-pci/pci-mt7621.c
@@ -489,7 +489,7 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 
 	DEASSERT_SYSRST_PCIE(val);
 
-	if ((*(unsigned int *)(0xbe00000c)&0xFFFF) == 0x0101) // MT7621 E2
+	if ((*(unsigned int *)(0xbe00000c) & 0xFFFF) == 0x0101) // MT7621 E2
 		bypass_pipe_rst(pcie);
 	set_phy_for_ssc(pcie);
 
-- 
1.9.1



^ permalink raw reply related	[flat|nested] 8+ messages in thread

* [PATCH 3/5] staging: mt7621-pci: spaces preferred around that '|'
  2018-10-04 16:29 [PATCH 0/5] staging: mt7621-pci: cleanup Mamta Shukla
  2018-10-04 16:32 ` [PATCH 1/5] staging: mt7621-pci: do not initialise statics to 0 Mamta Shukla
  2018-10-04 16:34 ` [PATCH 2/5] staging: mt7621-pci: spaces preferred around that '&' Mamta Shukla
@ 2018-10-04 16:35 ` Mamta Shukla
  2018-10-04 20:21   ` [Outreachy kernel] " Shraddha Barke
  2018-10-04 16:37 ` [PATCH 4/5] staging: mt7621-pci: spaces preferred around that '<<' Mamta Shukla
  2018-10-04 16:38 ` [PATCH 5/5] staging: mt7621-pci: Prefer using the BIT macro Mamta Shukla
  4 siblings, 1 reply; 8+ messages in thread
From: Mamta Shukla @ 2018-10-04 16:35 UTC (permalink / raw)
  To: outreachy-kernel; +Cc: mamtashukla555, gregkh

Add spaces around '|' to fix checkpatch issue
CHECK: spaces preferred around that '|' (ctx:VxV)

Signed-off-by: Mamta Shukla <mamtashukla555@gmail.com>
---
 drivers/staging/mt7621-pci/pci-mt7621.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/staging/mt7621-pci/pci-mt7621.c b/drivers/staging/mt7621-pci/pci-mt7621.c
index 14aac08..780ba56 100644
--- a/drivers/staging/mt7621-pci/pci-mt7621.c
+++ b/drivers/staging/mt7621-pci/pci-mt7621.c
@@ -644,7 +644,7 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 	switch (pcie_link_status) {
 	case 7:
 		val = read_config(pcie, 2, 0x4);
-		write_config(pcie, 2, 0x4, val|0x4);
+		write_config(pcie, 2, 0x4, val | 0x4);
 		val = read_config(pcie, 2, 0x70c);
 		val &= ~(0xff)<<8;
 		val |= 0x50<<8;
@@ -653,14 +653,14 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 	case 5:
 	case 6:
 		val = read_config(pcie, 1, 0x4);
-		write_config(pcie, 1, 0x4, val|0x4);
+		write_config(pcie, 1, 0x4, val | 0x4);
 		val = read_config(pcie, 1, 0x70c);
 		val &= ~(0xff)<<8;
 		val |= 0x50<<8;
 		write_config(pcie, 1, 0x70c, val);
 	default:
 		val = read_config(pcie, 0, 0x4);
-		write_config(pcie, 0, 0x4, val|0x4); //bus master enable
+		write_config(pcie, 0, 0x4, val | 0x4); //bus master enable
 		val = read_config(pcie, 0, 0x70c);
 		val &= ~(0xff)<<8;
 		val |= 0x50<<8;
-- 
1.9.1



^ permalink raw reply related	[flat|nested] 8+ messages in thread

* [PATCH 4/5] staging: mt7621-pci: spaces preferred around that '<<'
  2018-10-04 16:29 [PATCH 0/5] staging: mt7621-pci: cleanup Mamta Shukla
                   ` (2 preceding siblings ...)
  2018-10-04 16:35 ` [PATCH 3/5] staging: mt7621-pci: spaces preferred around that '|' Mamta Shukla
@ 2018-10-04 16:37 ` Mamta Shukla
  2018-10-04 16:38 ` [PATCH 5/5] staging: mt7621-pci: Prefer using the BIT macro Mamta Shukla
  4 siblings, 0 replies; 8+ messages in thread
From: Mamta Shukla @ 2018-10-04 16:37 UTC (permalink / raw)
  To: outreachy-kernel; +Cc: mamtashukla555, gregkh

Add spaces around '<<' to fix checkpatch issue.
CHECK: spaces preferred around that '<<' (ctx:VxV)

Signed-off-by: Mamta Shukla <mamtashukla555@gmail.com>
---
 drivers/staging/mt7621-pci/pci-mt7621.c | 40 ++++++++++++++++-----------------
 1 file changed, 20 insertions(+), 20 deletions(-)

diff --git a/drivers/staging/mt7621-pci/pci-mt7621.c b/drivers/staging/mt7621-pci/pci-mt7621.c
index 780ba56..31b448d 100644
--- a/drivers/staging/mt7621-pci/pci-mt7621.c
+++ b/drivers/staging/mt7621-pci/pci-mt7621.c
@@ -474,12 +474,12 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 
 	ASSERT_SYSRST_PCIE(RALINK_PCIE0_RST | RALINK_PCIE1_RST | RALINK_PCIE2_RST);
 
-	*(unsigned int *)(0xbe000060) &= ~(0x3<<10 | 0x3<<3);
-	*(unsigned int *)(0xbe000060) |= 0x1<<10 | 0x1<<3;
+	*(unsigned int *)(0xbe000060) &= ~(0x3 << 10 | 0x3 << 3);
+	*(unsigned int *)(0xbe000060) |= 0x1 << 10 | 0x1 << 3;
 	mdelay(100);
-	*(unsigned int *)(0xbe000600) |= 0x1<<19 | 0x1<<8 | 0x1<<7; // use GPIO19/GPIO8/GPIO7 (PERST_N/UART_RXD3/UART_TXD3)
+	*(unsigned int *)(0xbe000600) |= 0x1 << 19 | 0x1 << 8 | 0x1 << 7; // use GPIO19/GPIO8/GPIO7 (PERST_N/UART_RXD3/UART_TXD3)
 	mdelay(100);
-	*(unsigned int *)(0xbe000620) &= ~(0x1<<19 | 0x1<<8 | 0x1<<7);		// clear DATA
+	*(unsigned int *)(0xbe000620) &= ~(0x1 << 19 | 0x1 << 8 | 0x1 << 7);		// clear DATA
 
 	mdelay(100);
 
@@ -510,18 +510,18 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 	rt_sysc_m32(RALINK_PCIE_RST, 0, RALINK_RSTCTRL);
 
 	/* Use GPIO control instead of PERST_N */
-	*(unsigned int *)(0xbe000620) |= 0x1<<19 | 0x1<<8 | 0x1<<7;		// set DATA
+	*(unsigned int *)(0xbe000620) |= 0x1 << 19 | 0x1 << 8 | 0x1 << 7;		// set DATA
 	mdelay(1000);
 
 	if ((pcie_read(pcie, RT6855_PCIE0_OFFSET + RALINK_PCI_STATUS) & 0x1) == 0) {
 		printk("PCIE0 no card, disable it(RST&CLK)\n");
 		ASSERT_SYSRST_PCIE(RALINK_PCIE0_RST);
 		rt_sysc_m32(RALINK_PCIE0_CLK_EN, 0, RALINK_CLKCFG1);
-		pcie_link_status &= ~(1<<0);
+		pcie_link_status &= ~(1 << 0);
 	} else {
-		pcie_link_status |= 1<<0;
+		pcie_link_status |= 1 << 0;
 		val = pcie_read(pcie, RALINK_PCI_PCIMSK_ADDR);
-		val |= (1<<20); // enable pcie1 interrupt
+		val |= (1 << 20); // enable pcie1 interrupt
 		pcie_write(pcie, val, RALINK_PCI_PCIMSK_ADDR);
 	}
 
@@ -529,11 +529,11 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 		printk("PCIE1 no card, disable it(RST&CLK)\n");
 		ASSERT_SYSRST_PCIE(RALINK_PCIE1_RST);
 		rt_sysc_m32(RALINK_PCIE1_CLK_EN, 0, RALINK_CLKCFG1);
-		pcie_link_status &= ~(1<<1);
+		pcie_link_status &= ~(1 << 1);
 	} else {
-		pcie_link_status |= 1<<1;
+		pcie_link_status |= 1 << 1;
 		val = pcie_read(pcie, RALINK_PCI_PCIMSK_ADDR);
-		val |= (1<<21); // enable pcie1 interrupt
+		val |= (1 << 21); // enable pcie1 interrupt
 		pcie_write(pcie, val, RALINK_PCI_PCIMSK_ADDR);
 	}
 
@@ -541,11 +541,11 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 		printk("PCIE2 no card, disable it(RST&CLK)\n");
 		ASSERT_SYSRST_PCIE(RALINK_PCIE2_RST);
 		rt_sysc_m32(RALINK_PCIE2_CLK_EN, 0, RALINK_CLKCFG1);
-		pcie_link_status &= ~(1<<2);
+		pcie_link_status &= ~(1 << 2);
 	} else {
-		pcie_link_status |= 1<<2;
+		pcie_link_status |= 1 << 2;
 		val = pcie_read(pcie, RALINK_PCI_PCIMSK_ADDR);
-		val |= (1<<22); // enable pcie2 interrupt
+		val |= (1 << 22); // enable pcie2 interrupt
 		pcie_write(pcie, val, RALINK_PCI_PCIMSK_ADDR);
 	}
 
@@ -646,8 +646,8 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 		val = read_config(pcie, 2, 0x4);
 		write_config(pcie, 2, 0x4, val | 0x4);
 		val = read_config(pcie, 2, 0x70c);
-		val &= ~(0xff)<<8;
-		val |= 0x50<<8;
+		val &= ~(0xff) << 8;
+		val |= 0x50 << 8;
 		write_config(pcie, 2, 0x70c, val);
 	case 3:
 	case 5:
@@ -655,15 +655,15 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 		val = read_config(pcie, 1, 0x4);
 		write_config(pcie, 1, 0x4, val | 0x4);
 		val = read_config(pcie, 1, 0x70c);
-		val &= ~(0xff)<<8;
-		val |= 0x50<<8;
+		val &= ~(0xff) << 8;
+		val |= 0x50 << 8;
 		write_config(pcie, 1, 0x70c, val);
 	default:
 		val = read_config(pcie, 0, 0x4);
 		write_config(pcie, 0, 0x4, val | 0x4); //bus master enable
 		val = read_config(pcie, 0, 0x70c);
-		val &= ~(0xff)<<8;
-		val |= 0x50<<8;
+		val &= ~(0xff) << 8;
+		val |= 0x50 << 8;
 		write_config(pcie, 0, 0x70c, val);
 	}
 
-- 
1.9.1



^ permalink raw reply related	[flat|nested] 8+ messages in thread

* [PATCH 5/5] staging: mt7621-pci: Prefer using the BIT macro
  2018-10-04 16:29 [PATCH 0/5] staging: mt7621-pci: cleanup Mamta Shukla
                   ` (3 preceding siblings ...)
  2018-10-04 16:37 ` [PATCH 4/5] staging: mt7621-pci: spaces preferred around that '<<' Mamta Shukla
@ 2018-10-04 16:38 ` Mamta Shukla
  4 siblings, 0 replies; 8+ messages in thread
From: Mamta Shukla @ 2018-10-04 16:38 UTC (permalink / raw)
  To: outreachy-kernel; +Cc: mamtashukla555, gregkh

Replace all occurrences of (1<<x) with BIT(x).

Signed-off-by: Mamta Shukla <mamtashukla555@gmail.com>
---
 drivers/staging/mt7621-pci/pci-mt7621.c | 26 +++++++++++++-------------
 1 file changed, 13 insertions(+), 13 deletions(-)

diff --git a/drivers/staging/mt7621-pci/pci-mt7621.c b/drivers/staging/mt7621-pci/pci-mt7621.c
index 31b448d..8371a9c 100644
--- a/drivers/staging/mt7621-pci/pci-mt7621.c
+++ b/drivers/staging/mt7621-pci/pci-mt7621.c
@@ -475,11 +475,11 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 	ASSERT_SYSRST_PCIE(RALINK_PCIE0_RST | RALINK_PCIE1_RST | RALINK_PCIE2_RST);
 
 	*(unsigned int *)(0xbe000060) &= ~(0x3 << 10 | 0x3 << 3);
-	*(unsigned int *)(0xbe000060) |= 0x1 << 10 | 0x1 << 3;
+	*(unsigned int *)(0xbe000060) |=  BIT(10) | BIT(3);
 	mdelay(100);
-	*(unsigned int *)(0xbe000600) |= 0x1 << 19 | 0x1 << 8 | 0x1 << 7; // use GPIO19/GPIO8/GPIO7 (PERST_N/UART_RXD3/UART_TXD3)
+	*(unsigned int *)(0xbe000600) |= BIT(19) | BIT(8) | BIT(7); // use GPIO19/GPIO8/GPIO7 (PERST_N/UART_RXD3/UART_TXD3)
 	mdelay(100);
 	*(unsigned int *)(0xbe000620) &= ~(0x1 << 19 | 0x1 << 8 | 0x1 << 7);		// clear DATA
 
 	mdelay(100);
 
@@ -510,18 +510,18 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 	rt_sysc_m32(RALINK_PCIE_RST, 0, RALINK_RSTCTRL);
 
 	/* Use GPIO control instead of PERST_N */
 	*(unsigned int *)(0xbe000620) |= 0x1 << 19 | 0x1 << 8 | 0x1 << 7;		// set DATA
 	mdelay(1000);
 
 	if ((pcie_read(pcie, RT6855_PCIE0_OFFSET + RALINK_PCI_STATUS) & 0x1) == 0) {
 		printk("PCIE0 no card, disable it(RST&CLK)\n");
 		ASSERT_SYSRST_PCIE(RALINK_PCIE0_RST);
 		rt_sysc_m32(RALINK_PCIE0_CLK_EN, 0, RALINK_CLKCFG1);
-		pcie_link_status &= ~(1 << 0);
+		pcie_link_status &= ~(BIT(0));
 	} else {
-		pcie_link_status |= 1 << 0;
+		pcie_link_status |=  BIT(0);
 		val = pcie_read(pcie, RALINK_PCI_PCIMSK_ADDR);
-		val |= (1 << 20); // enable pcie1 interrupt
+		val |= BIT(20); // enable pcie1 interrupt
 		pcie_write(pcie, val, RALINK_PCI_PCIMSK_ADDR);
 	}
 
@@ -529,11 +529,11 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 		printk("PCIE1 no card, disable it(RST&CLK)\n");
 		ASSERT_SYSRST_PCIE(RALINK_PCIE1_RST);
 		rt_sysc_m32(RALINK_PCIE1_CLK_EN, 0, RALINK_CLKCFG1);
-		pcie_link_status &= ~(1 << 1);
+		pcie_link_status &= ~(BIT(1));
 	} else {
-		pcie_link_status |= 1 << 1;
+		pcie_link_status |= BIT(1);
 		val = pcie_read(pcie, RALINK_PCI_PCIMSK_ADDR);
-		val |= (1 << 21); // enable pcie1 interrupt
+		val |= BIT(21); // enable pcie1 interrupt
 		pcie_write(pcie, val, RALINK_PCI_PCIMSK_ADDR);
 	}
 
@@ -541,11 +541,11 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 		printk("PCIE2 no card, disable it(RST&CLK)\n");
 		ASSERT_SYSRST_PCIE(RALINK_PCIE2_RST);
 		rt_sysc_m32(RALINK_PCIE2_CLK_EN, 0, RALINK_CLKCFG1);
-		pcie_link_status &= ~(1 << 2);
+		pcie_link_status &= ~(BIT(2));
 	} else {
-		pcie_link_status |= 1 << 2;
+		pcie_link_status |=  BIT(2);
 		val = pcie_read(pcie, RALINK_PCI_PCIMSK_ADDR);
-		val |= (1 << 22); // enable pcie2 interrupt
+		val |= BIT(22); // enable pcie2 interrupt
 		pcie_write(pcie, val, RALINK_PCI_PCIMSK_ADDR);
 	}
 
@@ -475,11 +475,11 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 	mdelay(100);
-	*(unsigned int *)(0xbe000620) &= ~(0x1 << 19 | 0x1 << 8 | 0x1 << 7);		// clear DATA
+	*(unsigned int *)(0xbe000620) &= ~(BIT(19) | BIT(8) | BIT(7));		// clear DATA
 
 	mdelay(100);
@@ -510,18 +510,18 @@ static int mt7621_pci_probe(struct platform_device *pdev)
 
 	/* Use GPIO control instead of PERST_N */
-	*(unsigned int *)(0xbe000620) |= 0x1 << 19 | 0x1 << 8 | 0x1 << 7;		// set DATA
+	*(unsigned int *)(0xbe000620) |= BIT(19) | BIT(8) | BIT(7);		// set DATA
 	mdelay(1000);
 
-- 
1.9.1



^ permalink raw reply related	[flat|nested] 8+ messages in thread

* Re: [Outreachy kernel] [PATCH 1/5] staging: mt7621-pci: do not initialise statics to 0
  2018-10-04 16:32 ` [PATCH 1/5] staging: mt7621-pci: do not initialise statics to 0 Mamta Shukla
@ 2018-10-04 20:12   ` Shraddha Barke
  0 siblings, 0 replies; 8+ messages in thread
From: Shraddha Barke @ 2018-10-04 20:12 UTC (permalink / raw)
  To: Mamta Shukla; +Cc: outreachy-kernel, Greg Kroah-Hartman

[-- Attachment #1: Type: text/plain, Size: 1785 bytes --]

Hi Mamta

On Thu, Oct 4, 2018, 9:33 AM Mamta Shukla <mamtashukla555@gmail.com> wrote:

> Remove initialisation to 0 for static global variable to fix checkpatch
> issue.
> ERROR: do not initialise statics to 0
>
> Signed-off-by: Mamta Shukla <mamtashukla555@gmail.com>
> ---
> Removed initialisation to 0 for static global variable:
> 1.This type of variable iss initialised to 0 implicitly as per C coding
> standard.
> 2.Also this will take space in .BSS segment of memory while linking.
>

This series should've been a v2. If there are patches in a series which
haven't changed, you still send a v2 for them with the change log "No
change".


>  drivers/staging/mt7621-pci/pci-mt7621.c | 2 +-
>  1 file changed, 1 insertion(+), 1 deletion(-)
>
> diff --git a/drivers/staging/mt7621-pci/pci-mt7621.c
> b/drivers/staging/mt7621-pci/pci-mt7621.c
> index ba1f117..3182d8a 100644
> --- a/drivers/staging/mt7621-pci/pci-mt7621.c
> +++ b/drivers/staging/mt7621-pci/pci-mt7621.c
> @@ -122,7 +122,7 @@
>  #define RALINK_PCIE_CLK_EN             BIT(21)
>
>  #define MEMORY_BASE 0x0
> -static int pcie_link_status = 0;
> +static int pcie_link_status;
>
>  /**
>   * struct mt7621_pcie_port - PCIe port information
> --
> 1.9.1
>
> --
> You received this message because you are subscribed to the Google Groups
> "outreachy-kernel" group.
> To unsubscribe from this group and stop receiving emails from it, send an
> email to outreachy-kernel+unsubscribe@googlegroups.com.
> To post to this group, send email to outreachy-kernel@googlegroups.com.
> To view this discussion on the web visit
> https://groups.google.com/d/msgid/outreachy-kernel/dbd85c8647fdc02a03e1266568ac8b043bd6720d.1538670297.git.mamtashukla555%40gmail.com
> .
> For more options, visit https://groups.google.com/d/optout.
>

[-- Attachment #2: Type: text/html, Size: 3142 bytes --]

^ permalink raw reply	[flat|nested] 8+ messages in thread

* Re: [Outreachy kernel] [PATCH 3/5] staging: mt7621-pci: spaces preferred around that '|'
  2018-10-04 16:35 ` [PATCH 3/5] staging: mt7621-pci: spaces preferred around that '|' Mamta Shukla
@ 2018-10-04 20:21   ` Shraddha Barke
  0 siblings, 0 replies; 8+ messages in thread
From: Shraddha Barke @ 2018-10-04 20:21 UTC (permalink / raw)
  To: Mamta Shukla; +Cc: outreachy-kernel

[-- Attachment #1: Type: text/plain, Size: 2533 bytes --]

On Thu, Oct 4, 2018, 9:36 AM Mamta Shukla <mamtashukla555@gmail.com> wrote:

> Add spaces around '|' to fix checkpatch issue
> CHECK: spaces preferred around that '|' (ctx:VxV)
>

The subject line could say what change has been made instead of the
checkpatch message and also start the first word with a capital letter. :)

>
> Signed-off-by: Mamta Shukla <mamtashukla555@gmail.com>
> ---
>  drivers/staging/mt7621-pci/pci-mt7621.c | 6 +++---
>  1 file changed, 3 insertions(+), 3 deletions(-)
>
> diff --git a/drivers/staging/mt7621-pci/pci-mt7621.c
> b/drivers/staging/mt7621-pci/pci-mt7621.c
> index 14aac08..780ba56 100644
> --- a/drivers/staging/mt7621-pci/pci-mt7621.c
> +++ b/drivers/staging/mt7621-pci/pci-mt7621.c
> @@ -644,7 +644,7 @@ static int mt7621_pci_probe(struct platform_device
> *pdev)
>         switch (pcie_link_status) {
>         case 7:
>                 val = read_config(pcie, 2, 0x4);
> -               write_config(pcie, 2, 0x4, val|0x4);
> +               write_config(pcie, 2, 0x4, val | 0x4);
>                 val = read_config(pcie, 2, 0x70c);
>                 val &= ~(0xff)<<8;
>                 val |= 0x50<<8;
> @@ -653,14 +653,14 @@ static int mt7621_pci_probe(struct platform_device
> *pdev)
>         case 5:
>         case 6:
>                 val = read_config(pcie, 1, 0x4);
> -               write_config(pcie, 1, 0x4, val|0x4);
> +               write_config(pcie, 1, 0x4, val | 0x4);
>                 val = read_config(pcie, 1, 0x70c);
>                 val &= ~(0xff)<<8;
>                 val |= 0x50<<8;
>                 write_config(pcie, 1, 0x70c, val);
>         default:
>                 val = read_config(pcie, 0, 0x4);
> -               write_config(pcie, 0, 0x4, val|0x4); //bus master enable
> +               write_config(pcie, 0, 0x4, val | 0x4); //bus master enable
>                 val = read_config(pcie, 0, 0x70c);
>                 val &= ~(0xff)<<8;
>                 val |= 0x50<<8;
> --
> 1.9.1
>
> --
> You received this message because you are subscribed to the Google Groups
> "outreachy-kernel" group.
> To unsubscribe from this group and stop receiving emails from it, send an
> email to outreachy-kernel+unsubscribe@googlegroups.com.
> To post to this group, send email to outreachy-kernel@googlegroups.com.
> To view this discussion on the web visit
> https://groups.google.com/d/msgid/outreachy-kernel/2e3eb8f9b4461a330f292aa187158385800c56d4.1538670297.git.mamtashukla555%40gmail.com
> .
> For more options, visit https://groups.google.com/d/optout.
>

[-- Attachment #2: Type: text/html, Size: 3945 bytes --]

^ permalink raw reply	[flat|nested] 8+ messages in thread

end of thread, other threads:[~2018-10-04 20:22 UTC | newest]

Thread overview: 8+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2018-10-04 16:29 [PATCH 0/5] staging: mt7621-pci: cleanup Mamta Shukla
2018-10-04 16:32 ` [PATCH 1/5] staging: mt7621-pci: do not initialise statics to 0 Mamta Shukla
2018-10-04 20:12   ` [Outreachy kernel] " Shraddha Barke
2018-10-04 16:34 ` [PATCH 2/5] staging: mt7621-pci: spaces preferred around that '&' Mamta Shukla
2018-10-04 16:35 ` [PATCH 3/5] staging: mt7621-pci: spaces preferred around that '|' Mamta Shukla
2018-10-04 20:21   ` [Outreachy kernel] " Shraddha Barke
2018-10-04 16:37 ` [PATCH 4/5] staging: mt7621-pci: spaces preferred around that '<<' Mamta Shukla
2018-10-04 16:38 ` [PATCH 5/5] staging: mt7621-pci: Prefer using the BIT macro Mamta Shukla

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.